@@ -1,9 +1,10 @@
 import typer
 
-from pedroai import download
+from pedroai import download, notifications
 
 cli = typer.Typer()
 cli.command(name="download")(download.main)
+cli.command(name="pushcuts")(notifications.pushcuts_main)
 
 
 @cli.command()
